<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Los calendièrs son pas completament en <i>cache</i>",
"Everything seems to be completely cached" => "Tot sembla completament en <i>cache</i>",
"No calendars found." => "Cap de calendièr trobat.",
"No events found." => "Cap d'eveniment trobat.",
"Wrong calendar" => "Calendièr pas corrècte",
"You do not have the permissions to edit this event." => "Sias pas permés d'editar aqueste eveniment.",
"The file contained either no events or all events are already saved in your calendar." => "Lo fichièr contenguèt siá pas d'eveniments o totes los eveniments son ja enregistrats dins ton calendièr.",
"Import failed" => "Fracàs d'importacion",
"New Timezone:" => "Zona novèla :",
"Timezone changed" => "Zona cambiada",
"Invalid request" => "Demanda invalida",
"Calendar" => "Calendièr",
"Deletion failed" => "Fracàs d'escafatge",
"group" => "grop",
"can edit" => "pòt modificar",
"ddd" => "jjj",
"ddd M/d" => "jjj M/j",
"dddd M/d" => "jjjj M/j",
"MMMM yyyy" => "MMMM aaaa",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Dimenge",
"Monday" => "Diluns",
"Tuesday" => "Dimarç",
"Wednesday" => "Dimecres",
"Thursday" => "Dijòus",
"Friday" => "Divendres",
"Saturday" => "Dissabte",
"Sun." => "Dim.",
"Mon." => "Luns.",
"Tue." => "Març.",
"Wed." => "Mec.",
"Thu." => "Jòu.",
"Fri." => "Ven.",
"Sat." => "Sab.",
"January" => "genièr",
"February" => "febrièr",
"March" => "març",
"April" => "abril",
"May" => "mai",
"June" => "junh",
"July" => "julhet",
"August" => "agost",
"September" => "septembre",
"October" => "octobre",
"November" => "Novembre",
"December" => "Decembre",
"Jan." => "Gen.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Abr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Ago.",
"Sep." => "Sep.",
"Oct." => "Oct.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Totes los jorns",
"New Calendar" => "Calendièr novèl",
"Title" => "Títol",
"From Date" => "Dempuèi (data)",
"From Time" => "Dempuèi (ora) ",
"To Date" => "Cap a ~data~",
"To Time" => "Cap a ~ora~",
"The event ends before it starts" => "L'eveniment s'acaba avans sa debuta",
"There was a database fail" => "I a agut un fracàs de basa de donadas",
"Birthday" => "Anniversari",
"Business" => "Afar",
"Call" => "Crida",
"Clients" => "Practica",
"Deliverer" => "Liurason",
"Holidays" => "Vacanças",
"Ideas" => "Idèas",
"Journey" => "Viatge",
"Jubilee" => "Jubileu",
"Meeting" => "Encontra",
"Other" => "Autres",
"Personal" => "Personal",
"Projects" => "Projèctes",
"Questions" => "Questions",
"Work" => "Trabalh",
"by" => "per",
"unnamed" => "pas nomenat",
"You do not have the permissions to update this calendar." => "Sias pas permés de metre a jorn aqueste calendièr.",
"You do not have the permissions to delete this calendar." => "Sias pas permés d'escafar aqueste calendièr.",
"You do not have the permissions to add to this calendar." => "Sias pas permés d'apondre a 'n aqueste calendièr.",
"You do not have the permissions to add events to this calendar." => "Sias pas permés d'apondre eveniments a 'n aqueste calendièr.",
"You do not have the permissions to delete this event." => "Sias pas permés d'escafar aqueste eveniment.",
"Does not repeat" => "Torna pas far",
"Daily" => "Jornalièr",
"Weekly" => "Setmanièr",
"Every Weekday" => "Cada jorn de la setmana",
"Bi-Weekly" => "Dos setmanièr",
"Monthly" => "Mesadièr",
"Yearly" => "Annadièr",
"never" => "jamai",
"by occurrences" => "per ocurenças",
"by date" => "per data",
"by monthday" => "per jorn del mes",
"by weekday" => "per jorn de setmana",
"events week of month" => "eveniments setmanièrs del mes",
"first" => "primièr",
"second" => "second",
"third" => "tresen",
"fourth" => "quatren",
"fifth" => "cinquen",
"last" => "darrièr",
"by events date" => "per data d'eveniments",
"by yearday(s)" => "per jorn(s) d'annada",
"by weeknumber(s)" => "per numero(s) de setmana",
"by day and month" => "per jorn e mes",
"Date" => "Data",
"Cal." => "Cal.",
"Week" => "Setmana",
"Month" => "Mes",
"Today" => "Uèi",
"CalDav Link" => "Ligam CalDav",
"Timezone" => "Zona",
"Update timezone automatically" => "Zona mesa a jorn automaticament",
"Time format" => "Format de l'ora",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "La setmana comença lo",
"Cache" => "Cache",
"Clear cache for repeating events" => "Voida lo cache per los eveniments repetitius",
"Share Calendar" => "Parteja lo calendièr",
"Download" => "Avalcargar",
"Edit" => "Editar",
"Delete" => "Escafa",
"New calendar" => "Calendièr novèl",
"Edit calendar" => "Edita calendièr",
"Eventinfo" => "Eventinfo",
"Repeating" => "Al tornar far",
"Alarm" => "Alarma",
"Attendees" => "Convidats",
"Share" => "Parteja",
"Title of the Event" => "Títol del eveniment",
"All Day Event" => "Eveniment de cada jorn",
"Advanced options" => "Opcions avançadas",
"Location" => "Plaça",
"Edit categories" => "Edita categorias",
"Description" => "Descripcion",
"Repeat" => "Torna far",
"Advanced" => "Avançat",
"Select weekdays" => "Selecciona los jorns de setmana",
"Select days" => "Selecciona los jorns",
"and the events day of year." => "e los eveniments jornalièrs de l'annada.",
"and the events day of month." => "e los eveniments del mes.",
"Select months" => "Selecciona los meses",
"Select weeks" => "Selecciona las setmanas",
"and the events week of year." => "e los eveniments setmanièrs de l'annada.",
"Interval" => "Interval",
"End" => "Fin",
"occurrences" => "ocurréncias",
"create a new calendar" => "Crea un calendièr  novèl",
"Import a calendar file" => "Importa un fichièr calendièr",
"Please choose a calendar" => "Causís un calendièr, se te plai",
"Name of new calendar" => "Nom del calendièr novèl",
"Take an available name!" => "Pren-te un nom disponible !",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ja un calendièr amb lo meme nom existís. Se contunha aqueles seràn mesclats de tot biais.",
"Import" => "Importa",
"Close Dialog" => "Tampa lo dialòg",
"Create a new event" => "Crea un eveniment nòu",
"Unshare" => "Pas partejador",
"Shared via calendar" => "Partejat tras calendièr",
"View an event" => "Espiar un eveniment",
"Category" => "Categoria",
"No categories selected" => "Cap de categorias seleccionadas",
"From" => "De",
"at" => "a",
"To" => "Per"
);
